#!/bin/bash

## This is the script jenkins should run for app startup benchmarks

set -e

CMD_PREFIX="sudo -u phablet -i"
BENCHMARK_CMD="app-startup-benchmark.sh"


usage() {
	cat <<EOF
usage: $0 -a APP [-s ANDROID_SERIAL] [-Q] [-t TIMEOUT]

Benchmark the startup of APP

OPTIONS:
  -h	Show this message
  -s    Specify the serial of the device to install
  -a    The name of the application to start
  -Q    "Quick" don't do a reboot of the device before running the test
  -t	Time to wait for application startup (Default is 60)

EOF
}


main() {
	set -x
	if [ -z $QUICK ] ; then
		# get the phone in sane place
		adb reboot
		# sometimes reboot doesn't happen fast enough, so add a little
		# delay to help ensure its actually rebooted and we didn't just
		# connect back to the device before it rebooted
		adb wait-for-device
		sleep 5
		adb wait-for-device
		phablet-network --skip-setup -t 90s
	else
		echo "SKIPPING phone reboot..."
	fi

	echo "launching benchmark...."
	[ -z $ANDROID_SERIAL ] || ADBOPTS="-s $ANDROID_SERIAL"
	adb-shell ${CMD_PREFIX} ${BENCHMARK_CMD} $APP $TIMEOUT
}

while getopts p:s:a:Qh opt; do
    case $opt in
    h)
        usage
        exit 0
        ;;
    s)
        export ANDROID_SERIAL=$OPTARG
        ;;
    a)
        APP=$OPTARG
        ;;
    Q)
        QUICK=1
        ;;
    t)
	export TIMEOUT=$OPTARG
	;;
  esac
done

if [ -z $ANDROID_SERIAL ] ; then
    # ensure we only have one device attached
    lines=$(adb devices | wc -l)
    if [ $lines -gt 3 ] ; then
        echo "ERROR: More than one device attached, please use -s option"
	echo
        usage
        exit 1
    fi
fi
if [ -z $APP ] ; then
    echo "ERROR: No app specified"
    usage
    exit 1
fi


main
